import { useMutation, useQuery } from "@apollo/client";
import {
  IconButton,
  Paper,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
} from "@material-ui/core";
import React, { FC } from "react";
import { Article } from "../generated/graphql";
import EditIcon from "@material-ui/icons/Edit";
import { useRouter } from "@curi/react-dom";
import { ARTICLES, REMOVE_ARTICLE } from './articles.constants';
import { Delete } from '@material-ui/icons';

export const ArticleIndex: FC = () => {
  const { data } = useQuery<{
    articles: Article[];
  }>(ARTICLES, {});

  const [removeArticle] = useMutation<any, { id: string }>(REMOVE_ARTICLE);

  const router = useRouter();

  return (
    <section>
      <TableContainer component={Paper}>
        <Table aria-label="articles table">
          <TableHead>
            <TableRow>
              <TableCell>Article Title</TableCell>
              <TableCell>Published At</TableCell>
              <TableCell>Views</TableCell>
              <TableCell>Comments</TableCell>
              <TableCell>Actions</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {data?.articles.map((article) => (
              <TableRow key={article.id}>
                <TableCell component="th" scope="row">
                  {article.title}
                </TableCell>
                <TableCell>{article.publishedAt}</TableCell>
                <TableCell align="right"> -- </TableCell>
                <TableCell align="right"> -- </TableCell>
                <TableCell>
                  <IconButton
                    aria-label="edit"
                    onClick={() =>
                      router.navigate({
                        url: router.url({
                          name: "modify-article",
                          params: article,
                        }),
                      })
                    }
                  >
                    <EditIcon />
                  </IconButton>
                  <IconButton
                    aria-label="delete"
                    onClick={() =>
                      removeArticle({
                        variables: article,
                      })
                    }
                  >
                    <Delete />
                  </IconButton>
                </TableCell>
              </TableRow>
            ))}
          </TableBody>
        </Table>
      </TableContainer>
    </section>
  );
};
